Apache OpenDAL™ Hotpath Layer
opendal-layer-hotpath profiles OpenDAL operations and HTTP work with hotpath.
Use through opendal
Applications should normally enable this layer through the opendal facade with the
layers-hotpath feature:
cargo add opendal --features layers-hotpathThe layer is available as opendal::layers::HotpathLayer and can be
composed with an operator through opendal::Operator::layer.
Use with opendal-core
Add the split crates directly:
cargo add opendal-core opendal-layer-hotpathPass a configured layer to Operator::layer:
use opendal_core::Operator;
use opendal_layer_hotpath::HotpathLayer;
fn add_layer(operator: Operator, layer: HotpathLayer) -> Operator {
operator.layer(layer)
}Construct and configure layer as described in the API documentation before
composing it with an operator.
Documentation
License
Licensed under the Apache License, Version 2.0.
Structs
- Hotpath
Layer HotpathLayerprofiles every operation with hotpath.